==> zhongyan-manage-service-api-3.0.16-20221221.090458-8-sources.jar: cn/com/duiba/cloud/manage/service/api/model/dto/report/export/ExportYearPlanReviewData.java <==
package cn.com.duiba.cloud.manage.service.api.model.dto.report.export;

import com.alibaba.excel.annotation.ExcelProperty;
import lombok.Data;

/**
 * @Description  年度计划总览
 * @Date 2022/9/19 11:40
 * @Author LuHui
 */
@Data
public class ExportYearPlanReviewData {

    /**
     * 版块名称
     */
    @ExcelProperty("活动版块")
    private String templateName;

    /**
     * 活动次数合计
     */
    @ExcelProperty("合计")
    private Long count;
    /**
     * 1月一部
     */
    @ExcelProperty("一部")
    private Long januaryOneCount;
    /**
     * 1月二部
     */
    @ExcelProperty("二部")
    private Long januaryTwoCount;
    /**
     * 1月品牌部
     */
    @ExcelProperty("品牌")
    private Long januaryThreeCount;
    /**
     * 2月一部
     */
    @ExcelProperty("一部")
    private Long februaryOneCount;
    /**
     * 2月二部
     */
    @ExcelProperty("二部")
    private Long februaryTwoCount;
    /**
     * 2月品牌部
     */
    @ExcelProperty("品牌")
    private Long februaryThreeCount;
    /**
     * 3月一部
     */
    @ExcelProperty("一部")
    private Long marchOneCount;
    /**
     * 3月二部
     */
    @ExcelProperty("二部")
    private Long marchTwoCount;
    /**
     * 3月品牌部
     */
    @ExcelProperty("品牌")
    private Long marchThreeCount;
    /**
     * 4月一部
     */
    @ExcelProperty("一部")
    private Long aprilOneCount;
    /**
     * 4月二部
     */
    @ExcelProperty("二部")
    private Long aprilTwoCount;
    /**
     * 4月品牌部
     */
    @ExcelProperty("品牌")
    private Long aprilThreeCount;
    /**
     * 5月一部
     */
    @ExcelProperty("一部")
    private Long mayOneCount;
    /**
     * 5月二部
     */
    @ExcelProperty("二部")
    private Long mayTwoCount;
    /**
     * 5月品牌部
     */
    @ExcelProperty("品牌")
    private Long mayThreeCount;
    /**
     * 6月一部
     */
    @ExcelProperty("一部")
    private Long juneOneCount;
    /**
     * 6月二部
     */
    @ExcelProperty("二部")
    private Long juneTwoCount;
    /**
     * 6月品牌部
     */
    @ExcelProperty("品牌")
    private Long juneThreeCount;
    /**
     * 7月一部
     */
    @ExcelProperty("一部")
    private Long julyOneCount;
    /**
     * 7月二部
     */
    @ExcelProperty("二部")
    private Long julyTwoCount;
    /**
     * 7月品牌部
     */
    @ExcelProperty("品牌")
    private Long julyThreeCount;
    /**
     * 8月一部
     */
    @ExcelProperty("一部")
    private Long augustOneCount;
    /**
     * 8月二部
     */
    @ExcelProperty("二部")
    private Long augustTwoCount;
    /**
     * 8月品牌部
     */
    @ExcelProperty("品牌")
    private Long augustThreeCount;
    /**
     * 9月一部
     */
    @ExcelProperty("一部")
    private Long septemberOneCount;
    /**
     * 9月二部
     */
    @ExcelProperty("二部")
    private Long septemberTwoCount;
    /**
     * 9月品牌部
     */
    @ExcelProperty("品牌")
    private Long septemberThreeCount;
    /**
     * 10月一部
     */
    @ExcelProperty("一部")
    private Long octoberOneCount;
    /**
     * 10月二部
     */
    @ExcelProperty("二部")
    private Long octoberTwoCount;
    /**
     * 10月品牌部
     */
    @ExcelProperty("品牌")
    private Long octoberThreeCount;
    /**
     * 11月一部
     */
    @ExcelProperty("一部")
    private Long novemberOneCount;
    /**
     * 11月二部
     */
    @ExcelProperty("二部")
    private Long novemberTwoCount;
    /**
     * 11月品牌部
     */
    @ExcelProperty("品牌")
    private Long novemberThreeCount;
    /**
     * 12月一部
     */
    @ExcelProperty("一部")
    private Long decemberOneCount;
    /**
     * 12月二部
     */
    @ExcelProperty("二部")
    private Long decemberTwoCount;
    /**
     * 12月品牌部
     */
    @ExcelProperty("品牌")
    private Long decemberThreeCount;
    /**
     * 全年一部
     */
    @ExcelProperty("一部")
    private Long yearOneCount;
    /**
     * 全年二部
     */
    @ExcelProperty("二部")
    private Long yearTwoCount;
    /**
     * 全年品牌部
     */
    @ExcelProperty("品牌")
    private Long yearThreeCount;
    /**
     * 负责人
     */
    @ExcelProperty("负责人")
    private String username;


}

==> zhongyan-manage-service-api-3.0.39-20230712.071454-10-sources.jar: cn/com/duiba/cloud/manage/service/api/model/dto/report/export/ExportYearPlanReviewData.java <==
package cn.com.duiba.cloud.manage.service.api.model.dto.report.export;

import com.alibaba.excel.annotation.ExcelProperty;
import lombok.Data;

/**
 * @Description  年度计划总览
 * @Date 2022/9/19 11:40
 * @Author LuHui
 */
@Data
public class ExportYearPlanReviewData {

    /**
     * 版块名称
     */
    @ExcelProperty("运营项目")
    private String templateName;

    /**
     * 活动次数合计
     */
    @ExcelProperty("合计")
    private Long count;
    /**
     * 1月一部
     */
    @ExcelProperty("一部")
    private Long januaryOneCount;
    /**
     * 1月二部
     */
    @ExcelProperty("二部")
    private Long januaryTwoCount;
    /**
     * 1月品牌部
     */
    @ExcelProperty("品牌")
    private Long januaryThreeCount;
    /**
     * 2月一部
     */
    @ExcelProperty("一部")
    private Long februaryOneCount;
    /**
     * 2月二部
     */
    @ExcelProperty("二部")
    private Long februaryTwoCount;
    /**
     * 2月品牌部
     */
    @ExcelProperty("品牌")
    private Long februaryThreeCount;
    /**
     * 3月一部
     */
    @ExcelProperty("一部")
    private Long marchOneCount;
    /**
     * 3月二部
     */
    @ExcelProperty("二部")
    private Long marchTwoCount;
    /**
     * 3月品牌部
     */
    @ExcelProperty("品牌")
    private Long marchThreeCount;
    /**
     * 4月一部
     */
    @ExcelProperty("一部")
    private Long aprilOneCount;
    /**
     * 4月二部
     */
    @ExcelProperty("二部")
    private Long aprilTwoCount;
    /**
     * 4月品牌部
     */
    @ExcelProperty("品牌")
    private Long aprilThreeCount;
    /**
     * 5月一部
     */
    @ExcelProperty("一部")
    private Long mayOneCount;
    /**
     * 5月二部
     */
    @ExcelProperty("二部")
    private Long mayTwoCount;
    /**
     * 5月品牌部
     */
    @ExcelProperty("品牌")
    private Long mayThreeCount;
    /**
     * 6月一部
     */
    @ExcelProperty("一部")
    private Long juneOneCount;
    /**
     * 6月二部
     */
    @ExcelProperty("二部")
    private Long juneTwoCount;
    /**
     * 6月品牌部
     */
    @ExcelProperty("品牌")
    private Long juneThreeCount;
    /**
     * 7月一部
     */
    @ExcelProperty("一部")
    private Long julyOneCount;
    /**
     * 7月二部
     */
    @ExcelProperty("二部")
    private Long julyTwoCount;
    /**
     * 7月品牌部
     */
    @ExcelProperty("品牌")
    private Long julyThreeCount;
    /**
     * 8月一部
     */
    @ExcelProperty("一部")
    private Long augustOneCount;
    /**
     * 8月二部
     */
    @ExcelProperty("二部")
    private Long augustTwoCount;
    /**
     * 8月品牌部
     */
    @ExcelProperty("品牌")
    private Long augustThreeCount;
    /**
     * 9月一部
     */
    @ExcelProperty("一部")
    private Long septemberOneCount;
    /**
     * 9月二部
     */
    @ExcelProperty("二部")
    private Long septemberTwoCount;
    /**
     * 9月品牌部
     */
    @ExcelProperty("品牌")
    private Long septemberThreeCount;
    /**
     * 10月一部
     */
    @ExcelProperty("一部")
    private Long octoberOneCount;
    /**
     * 10月二部
     */
    @ExcelProperty("二部")
    private Long octoberTwoCount;
    /**
     * 10月品牌部
     */
    @ExcelProperty("品牌")
    private Long octoberThreeCount;
    /**
     * 11月一部
     */
    @ExcelProperty("一部")
    private Long novemberOneCount;
    /**
     * 11月二部
     */
    @ExcelProperty("二部")
    private Long novemberTwoCount;
    /**
     * 11月品牌部
     */
    @ExcelProperty("品牌")
    private Long novemberThreeCount;
    /**
     * 12月一部
     */
    @ExcelProperty("一部")
    private Long decemberOneCount;
    /**
     * 12月二部
     */
    @ExcelProperty("二部")
    private Long decemberTwoCount;
    /**
     * 12月品牌部
     */
    @ExcelProperty("品牌")
    private Long decemberThreeCount;
    /**
     * 全年一部
     */
    @ExcelProperty("一部")
    private Long yearOneCount;
    /**
     * 全年二部
     */
    @ExcelProperty("二部")
    private Long yearTwoCount;
    /**
     * 全年品牌部
     */
    @ExcelProperty("品牌")
    private Long yearThreeCount;
    /**
     * 负责人
     */
    @ExcelProperty("负责人")
    private String username;


}
